"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const React = require("react");
const GetFields_1 = require("./GetFields");
function getAnnotationsLibraryPage(superdesk) {
    return class AnnotationsLibraryPage extends React.Component {
        render() {
            const { gettext } = superdesk.localization;
            const { getGenericListPageComponent, ListItem, ListItemColumn, ListItemActionsMenu, } = superdesk.components;
            const { getFormFieldPreviewComponent } = superdesk.forms;
            const { nameField, languageField, definitionField, } = GetFields_1.getFields(superdesk);
            const formConfig = {
                direction: 'vertical',
                type: 'inline',
                form: [
                    nameField,
                    languageField,
                    definitionField,
                ],
            };
            const AnnotationsLibraryPageComponent = getGenericListPageComponent('concept_items', formConfig);
            const renderRow = (key, item, page) => (React.createElement(ListItem, { key: key, onClick: () => page.openPreview(item._id) },
                React.createElement(ListItemColumn, { bold: true, noBorder: true }, getFormFieldPreviewComponent(item, nameField)),
                React.createElement(ListItemColumn, { ellipsisAndGrow: true, noBorder: true }, getFormFieldPreviewComponent(item, definitionField, { showAsPlainText: true })),
                React.createElement(ListItemActionsMenu, null,
                    React.createElement("div", { style: { display: 'flex' } },
                        React.createElement("button", { onClick: (e) => {
                                e.stopPropagation();
                                page.startEditing(item._id);
                            }, title: gettext('Edit') },
                            React.createElement("i", { className: "icon-pencil" })),
                        React.createElement("button", { onClick: (e) => {
                                e.stopPropagation();
                                page.deleteItem(item);
                            }, title: gettext('Remove') },
                            React.createElement("i", { className: "icon-trash" }))))));
            return (React.createElement(AnnotationsLibraryPageComponent, { defaultSortOption: { field: 'name', direction: 'ascending' }, formConfig: formConfig, renderRow: renderRow, newItemTemplate: { cpnat_type: 'cpnat:abstract' }, fieldForSearch: nameField, defaultFilters: { language: superdesk.instance.config.language || 'en' } }));
        }
    };
}
exports.getAnnotationsLibraryPage = getAnnotationsLibraryPage;
