"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const AnnotationInputWithKnowledgeBase_1 = require("./AnnotationInputWithKnowledgeBase");
const annotations_library_page_1 = require("./annotations-library-page");
const GetFields_1 = require("./GetFields");
const RESOURCE = 'concept_items';
function annotationExistsInKnowledgeBase(superdesk, annotationText) {
    const { dataApi } = superdesk;
    const { nameField } = GetFields_1.getFields(superdesk);
    const { generateFilterForServer } = superdesk.forms;
    return dataApi.query(RESOURCE, 1, { field: 'name', direction: 'ascending' }, { name: generateFilterForServer(nameField.type, annotationText) }).then((res) => res._items.length > 0);
}
function annotationFromLibraryTabSelectedByDefault(superdesk, annotationText, mode) {
    const { assertNever } = superdesk.helpers;
    if (mode === 'edit') {
        return Promise.resolve(false);
    }
    else if (mode === 'create') {
        return annotationExistsInKnowledgeBase(superdesk, annotationText);
    }
    else {
        return assertNever(mode);
    }
}
function onAnnotationCreate(superdesk, language, annotationText, definitionHtml) {
    annotationExistsInKnowledgeBase(superdesk, annotationText)
        .then((exists) => {
        // Don't create a knowledge base item for that annotation if it already exists
        if (!exists) {
            superdesk.dataApi.create(RESOURCE, {
                language: language,
                name: annotationText,
                definition_html: definitionHtml,
                cpnat_type: 'cpnat:abstract',
            });
        }
    });
}
var extension = {
    activate: (superdesk) => {
        const { gettext } = superdesk.localization;
        return Promise.resolve({
            contributions: {
                editor3: {
                    annotationInputTabs: [
                        {
                            label: gettext('Annotations library'),
                            component: AnnotationInputWithKnowledgeBase_1.getAnnotationInputWithKnowledgeBase(superdesk),
                            selectedByDefault: (annotationText, mode) => annotationFromLibraryTabSelectedByDefault(superdesk, annotationText, mode),
                            onAnnotationCreate: (language, annotationText, definitionHtml) => {
                                return onAnnotationCreate(superdesk, language, annotationText, definitionHtml);
                            },
                        },
                    ],
                },
                pages: [
                    {
                        title: gettext('Annotations library'),
                        url: '/annotations-library',
                        component: annotations_library_page_1.getAnnotationsLibraryPage(superdesk),
                    },
                ],
            },
        });
    },
};
exports.default = extension;
