"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getHeaderAutoTaggingComponent = void 0;
const React = require("react");
const immutable_1 = require("immutable");
const tag_list_1 = require("./tag-list");
const adapter_1 = require("./adapter");
const groups_1 = require("./groups");
const data_transformations_1 = require("./data-transformations");
const auto_tagging_1 = require("./auto-tagging");
function getHeaderAutoTaggingComponent(superdesk) {
    const TagListComponent = tag_list_1.getTagsListComponent(superdesk);
    const groupLabels = groups_1.getGroups(superdesk);
    return class HeaderAutoTagging extends React.PureComponent {
        constructor() {
            var _a;
            super(...arguments);
            this.iMatricsFields = (_a = superdesk.instance.config.iMatricsFields) !== null && _a !== void 0 ? _a : { entities: {}, others: {} };
        }
        render() {
            const existingTags = data_transformations_1.getExistingTags(this.props.article);
            const resClient = adapter_1.toClientFormat(existingTags);
            const data = { original: { analysis: resClient }, changes: { analysis: resClient } };
            const { entitiesGroupedAndSorted, othersGrouped } = auto_tagging_1.getAutoTaggingData(data, this.iMatricsFields);
            const savedTags = data.original.analysis.keySeq().toSet();
            let allGrouped = immutable_1.OrderedMap();
            othersGrouped.forEach((tags, groupId) => {
                if (tags != null && groupId != null) {
                    allGrouped = allGrouped.set(groupId, React.createElement("div", null,
                        React.createElement(TagListComponent, { savedTags: savedTags, tags: tags.toMap(), readOnly: true, inline: true, onRemove: () => true })));
                }
            });
            if (entitiesGroupedAndSorted.size > 0) {
                allGrouped = allGrouped.set('entities', React.createElement("div", null, entitiesGroupedAndSorted.map((tags, key) => (React.createElement("div", { key: key },
                    React.createElement("div", { className: "form-label", style: { display: 'block' } }, groupLabels.get(key).plural),
                    React.createElement(TagListComponent, { savedTags: savedTags, tags: tags.toMap(), readOnly: true, inline: true, onRemove: () => true })))).toArray()));
            }
            const allGroupedAndSortedByConfig = allGrouped
                .filter((_, key) => auto_tagging_1.hasConfig(key, this.iMatricsFields.others))
                .sortBy((_, key) => this.iMatricsFields.others[key].order, (a, b) => a - b);
            const allGroupedAndSortedNotInConfig = allGrouped
                .filter((_, key) => !auto_tagging_1.hasConfig(key, this.iMatricsFields.others));
            const allGroupedAndSorted = allGroupedAndSortedByConfig
                .concat(allGroupedAndSortedNotInConfig);
            return (allGroupedAndSorted.map((item) => item).toArray());
        }
    };
}
exports.getHeaderAutoTaggingComponent = getHeaderAutoTaggingComponent;
