"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getTagsListComponent = void 0;
const React = require("react");
const react_1 = require("superdesk-ui-framework/react");
const lodash_1 = require("lodash");
const tag_popover_1 = require("./tag-popover");
function getTagsListComponent(superdesk) {
    const { gettext } = superdesk.localization;
    const { arrayToTree, treeToArray } = superdesk.utilities;
    return class TagList extends React.PureComponent {
        render() {
            const { tags, onRemove, readOnly, savedTags, inline } = this.props;
            const tagsJs = Object.values(tags.toJS());
            const tagsTree = arrayToTree(tagsJs, (item) => item.qcode, (item) => item.parent).result;
            const tagListItem = (node) => {
                const isRootNodeWithChildren = node.parent == null && node.children != null;
                const item = node.value;
                return (React.createElement(tag_popover_1.TagPopover, { tag: item, key: item.qcode, gettext: gettext, 
                    // root items with children have to be on a separate line
                    display: isRootNodeWithChildren && !inline ? 'block' : undefined },
                    React.createElement(react_1.Tag, { key: item.qcode, text: item.name, readOnly: readOnly, shade: savedTags.has(item.qcode) && !readOnly ?
                            (isRootNodeWithChildren ? 'highlight2' : 'highlight1') :
                            (isRootNodeWithChildren ? 'darker' : 'light'), onClick: readOnly
                            ? lodash_1.noop
                            : () => {
                                onRemove(treeToArray([node]).map(({ qcode }) => qcode));
                            } })));
            };
            function renderTreeNode(treeNodes, level = 0) {
                const treeNodesMap = treeNodes.map((node) => (React.createElement(React.Fragment, { key: node.value.qcode },
                    tagListItem(node),
                    node.children != null && renderTreeNode(node.children, level + 1))));
                return (!inline ? (React.createElement("div", { style: { paddingLeft: level === 0 || inline ? 0 : 14 } }, treeNodesMap)) : (React.createElement(React.Fragment, null,
                    level === 0 ? '' : ' | ',
                    treeNodesMap)));
            }
            return renderTreeNode(tagsTree);
        }
    };
}
exports.getTagsListComponent = getTagsListComponent;
