"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getTemplateDateTimeField = void 0;
const React = require("react");
const extension_1 = require("./extension");
const superdesk_ui_framework_1 = require("superdesk-ui-framework");
const getDateTimeField_1 = require("./getDateTimeField");
const react_1 = require("superdesk-ui-framework/react");
const addMinutes_1 = require("date-fns/addMinutes");
function getTemplateDateTimeField(superdesk) {
    const { Spacer } = superdesk.components;
    const currentDateTime = '{{ now|iso_datetime }}';
    const DateTimeField = getDateTimeField_1.getDateTimeField(superdesk);
    const { dateToServerString } = superdesk.utilities;
    const { assertNever } = superdesk.helpers;
    return class TemplateDateTimeField extends React.PureComponent {
        constructor(props) {
            super(props);
            this.state = {
                radioValue: extension_1.isDateValue(this.props.value) ? 'showDate' : 'setCurrentDate',
                previousValue: new Date(),
            };
            this.onRadioValueChange = this.onRadioValueChange.bind(this);
        }
        onRadioValueChange(radioValue) {
            this.setState({ radioValue });
            if (radioValue === 'setCurrentDate') {
                this.props.setValue(currentDateTime);
            }
            else if (radioValue === 'showDate') {
                this.props.setValue(dateToServerString(this.state.previousValue));
            }
            else {
                assertNever(radioValue);
            }
        }
        render() {
            const { item, value, readOnly, config } = this.props;
            const checkbox = (React.createElement(react_1.Switch, { value: this.props.value != null, onChange: (val) => {
                    if (val) {
                        this.props.setValue(dateToServerString(addMinutes_1.default(new Date(), this.props.config.initial_offset_minutes)));
                    }
                    else {
                        this.props.setValue(null);
                    }
                } }));
            const radiobutton = (React.createElement(superdesk_ui_framework_1.CheckGroup, null,
                React.createElement(superdesk_ui_framework_1.Radio, { value: this.props.value || undefined, options: [
                        {
                            value: 'setCurrentDate',
                            label: 'Always choose current date',
                        },
                        {
                            value: 'showDate',
                            label: 'Choose a date',
                        },
                    ], onChange: (val) => this.onRadioValueChange(val) })));
            return (React.createElement(Spacer, { type: "horizontal", align: "center", spacing: "medium" },
                checkbox,
                value && radiobutton,
                this.state.radioValue === 'showDate' && (React.createElement(DateTimeField, { item: item, value: value, setValue: this.props.setValue, readOnly: readOnly, config: config, hideToggle: true }))));
        }
    };
}
exports.getTemplateDateTimeField = getTemplateDateTimeField;
