"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const lodash_1 = require("lodash");
const get_mark_for_user_modal_1 = require("./get-mark-for-user-modal");
function getActionsBulkInitialize(superdesk) {
    const { gettext } = superdesk.localization;
    const { isPersonal, isLocked } = superdesk.entities.article;
    return function getActionsBulk(articles) {
        // it doesn't make sense to display the action since it wouldn't get updated in the list anyway
        // when article is locked for editing all changes are temporary
        // and aren't displayed in the list item until the article is saved
        const someItemsLocked = articles.some(isLocked);
        if (articles.some(isPersonal) || someItemsLocked) {
            return Promise.resolve([]);
        }
        const selectedUserIds = lodash_1.uniq(articles
            .map((item) => item.marked_for_user)
            .filter((marked_for_user) => marked_for_user != null));
        const initialUserId = selectedUserIds[0];
        const selectedUserIdInitial = selectedUserIds.length > 1 || initialUserId === null
            ? undefined
            : initialUserId;
        const message = selectedUserIds.length > 1
            ? gettext('Items are marked for different users')
            : undefined;
        return Promise.resolve([{
                label: gettext('Mark for user'),
                icon: 'icon-assign',
                onTrigger: () => {
                    superdesk.ui.showModal(get_mark_for_user_modal_1.getMarkForUserModal(superdesk, (selectedUserId) => {
                        articles.forEach((article) => {
                            superdesk.entities.article.update(Object.assign({}, article, { marked_for_user: selectedUserId }));
                        });
                    }, false, selectedUserIdInitial, message));
                },
            }]);
    };
}
exports.getActionsBulkInitialize = getActionsBulkInitialize;
