"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const managed_marked_user_1 = require("./managed-marked-user");
function getActionsInitialize(superdesk) {
    const { gettext } = superdesk.localization;
    const { isPersonal, isLocked } = superdesk.entities.article;
    return function getActions(articleNext) {
        // it doesn't make sense to display the action since it wouldn't get updated in the list anyway
        // when article is locked for editing all changes are temporary
        // and aren't displayed in the list item until the article is saved
        const locked = isLocked(articleNext);
        if (isPersonal(articleNext) || locked) {
            return Promise.resolve([]);
        }
        const markForUser = {
            label: gettext('Mark for user'),
            icon: 'icon-assign',
            groupId: 'highlights',
            onTrigger: () => {
                managed_marked_user_1.manageMarkedUserForSingleArticle(superdesk, articleNext);
            },
        };
        const unmark = {
            label: gettext('Unmark user'),
            icon: 'icon-assign',
            groupId: 'highlights',
            onTrigger: () => {
                superdesk.entities.article.update(Object.assign({}, articleNext, { marked_for_user: null }));
            },
        };
        const markForOtherUser = {
            label: gettext('Mark for other user'),
            groupId: 'highlights',
            icon: 'icon-assign',
            onTrigger: () => {
                managed_marked_user_1.manageMarkedUserForSingleArticle(superdesk, articleNext);
            },
        };
        const assigned = articleNext.marked_for_user != null;
        if (assigned) {
            return Promise.resolve([unmark, markForOtherUser]);
        }
        else {
            return Promise.resolve([markForUser]);
        }
    };
}
exports.getActionsInitialize = getActionsInitialize;
